:mod:`merkletree` --- A NEO specific Merkle Patricia Tree implementation
========================================================================

This is a pure python implementation of a Merkle Patricia Tree that works on and returns hashes using NEOs :class:`~neo3.core.types.UInt256` types.

For more information on the usage within the NEO system see `their website <https://docs.neo.org/developerguide/en/articles/cryptography/merkle_tree.html>`_.


.. autoclass:: neo3.core.cryptography.merkletree.MerkleTree
   :members:
   :undoc-members:
   :show-inheritance:
   